# -*- coding: utf-8 -*-
from setuphelpers import *
import win32net

openvpn_config_folder = makepath(programfiles64, 'OpenVPN', 'config')
member_allow_to_vpn = r'CONTOSO\GG_VPN'
openvpn_group_name = r'OpenVPN Administrators'

def create_group_with_check(groupname):
    try:
        create_group(groupname)
        print(f"Local group {groupname} successfully created")
    except win32net.error as e:
        if e.winerror == 1379:
            print(f"Local group {groupname} already exists !")

def add_member_to_group(member, groupname):
    if member not in local_group_members(groupname):
        add_user_to_group(member, groupname)
        
def remove_member_from_group(member, groupname):
    if member in local_group_members(groupname):
        remove_user_from_group(member, groupname)

def install():
    print(f"Creating the {openvpn_group_name} group and adding the {member_allow_to_vpn} group as a member")
        
    create_group_with_check(openvpn_group_name)
    add_member_to_group(member_allow_to_vpn, openvpn_group_name)
    
    # Comment this part if not needed
    print("Importing the VPN config")
    
    mkdirs(openvpn_config_folder)

    # Importation of the vpn configuration file
    for f in glob.glob('*.ovpn'):
        if not (isfile(f)):
            print(f"Copy config '{f}' to OpenVPN config folder")
            filecopyto(f, openvpn_config_folder)
        else:
            print(f"Config file '{f}' already in folder")
  
def uninstall():
    print(f"Deleting vpn configuration files")
    if isdir(openvpn_config_folder):
        remove_tree(openvpn_config_folder)
    
    print(f"Deleting the member {member_allow_to_vpn} into {openvpn_group_name}")
    remove_member_from_group(member_allow_to_vpn, openvpn_group_name)